==> haskell-lambdabot-trusted-5.3.1.2-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lambdabot-trusted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lambdabot-trusted
version:              5.3.1.2
visibility:           public
id:                   lambdabot-trusted-5.3.1.2-33KfQVja30AJf39sAWLJBi
key:                  lambdabot-trusted-5.3.1.2-33KfQVja30AJf39sAWLJBi
license:              LicenseRef-GPL
maintainer:           Naïm Favier <n@monade.li>
author:               Bertram Felgenhauer
homepage:             https://wiki.haskell.org/Lambdabot
synopsis:             Lambdabot trusted code.
description:
    Lambdabot is an IRC bot written over several years by
    those on the #haskell IRC channel.

    This small package provides functions used by
    the \@run command.

category:             Development, Web
abi:                  5ec70854bd2b74804ff9fc842ba6e07e
exposed:              True
exposed-modules:      Lambdabot.Plugin.Haskell.Eval.Trusted
hidden-modules:       Lambdabot.Plugin.Haskell.Check.ShowQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lambdabot-trusted
hs-libraries:         HSlambdabot-trusted-5.3.1.2-33KfQVja30AJf39sAWLJBi
depends:
    QuickCheck-2.14.3-5xMqTFfEVh35pIkOsqqnaD
    QuickCheck-safe-0.1.0.6-51wu72hDSkEF1SiQ8UkcDf base-4.17.2.1
    oeis-0.3.10.1-5Tuz2Z8F4Gb46ghPxUUW3a

haddock-interfaces:
    /usr/share/doc/haskell-lambdabot-trusted/html/lambdabot-trusted.haddock

haddock-html:         /usr/share/doc/haskell-lambdabot-trusted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lambdabot-trusted-5.3.1.2-125-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lambdabot-trusted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lambdabot-trusted
version:              5.3.1.2
visibility:           public
id:                   lambdabot-trusted-5.3.1.2-HIB8PNkMjWA5uyhS2zp2AY
key:                  lambdabot-trusted-5.3.1.2-HIB8PNkMjWA5uyhS2zp2AY
license:              LicenseRef-GPL
maintainer:           Naïm Favier <n@monade.li>
author:               Bertram Felgenhauer
homepage:             https://wiki.haskell.org/Lambdabot
synopsis:             Lambdabot trusted code.
description:
    Lambdabot is an IRC bot written over several years by
    those on the #haskell IRC channel.

    This small package provides functions used by
    the \@run command.

category:             Development, Web
abi:                  6afeb4cd045a86130c0ddf3072a545cd
exposed:              True
exposed-modules:      Lambdabot.Plugin.Haskell.Eval.Trusted
hidden-modules:       Lambdabot.Plugin.Haskell.Check.ShowQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lambdabot-trusted
hs-libraries:         HSlambdabot-trusted-5.3.1.2-HIB8PNkMjWA5uyhS2zp2AY
depends:
    QuickCheck-2.14.3-5xMqTFfEVh35pIkOsqqnaD
    QuickCheck-safe-0.1.0.6-51wu72hDSkEF1SiQ8UkcDf base-4.17.2.1
    oeis-0.3.10.1-HvSJnGEKIpZCgKe0q3Awfc

haddock-interfaces:
    /usr/share/doc/haskell-lambdabot-trusted/html/lambdabot-trusted.haddock

haddock-html:         /usr/share/doc/haskell-lambdabot-trusted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
